@@ -25,3 +25,9 @@ from .is_jwt import *
 from .is_md5 import *
 from .is_port import *
 from .is_ip import *
+from .is_semantic_version import *
+from .is_hexadecimal import *
+from .is_mongo_id import *
+from .is_uppercase import *
+from .is_slug import *
+from .is_full_width import *
